package com.cm.common.plugin.service.systemlogger;

import com.cm.common.exception.RemoveException;
import com.cm.common.exception.SaveException;
import com.cm.common.exception.SearchException;
import com.cm.common.exception.UpdateException;
import com.cm.common.pojo.ListPage;
import com.cm.common.result.SuccessResult;
import com.cm.common.result.SuccessResultList;
import com.cm.common.plugin.pojo.dtos.systemlogger.SystemLoggerDTO;

import java.util.List;
import java.util.Map;

/**
 * @ClassName: ISystemLoggerService
 * @Description: 系统日志
 * @Author: admin
 * @Date: 2019-05-28 17:42:45
 * @Version: 1.0
 **/
public interface ISystemLoggerService {

    /**
     * 新增系统日志
     *
     * @param params
     * @return
     * @throws SaveException
     */
    SuccessResult saveSystemLogger(Map<String, Object> params) throws SaveException, SearchException;

    /**
     * 删除系统日志
     *
     * @param params
     * @return
     * @throws RemoveException
     */
    SuccessResult removeSystemLogger(Map<String, Object> params) throws RemoveException;

    /**
     * 修改系统日志
     *
     * @param params
     * @return
     * @throws UpdateException
     */
    SuccessResult updateSystemLogger(Map<String, Object> params) throws UpdateException;

    /**
     * 全部系统日志列表
     *
     * @param params
     * @return
     * @throws SearchException
     */
    List<SystemLoggerDTO> listSystemLoggerAll(Map<String, Object> params) throws SearchException;

    /**
     * 系统日志详情
     *
     * @param params
     * @return
     * @throws SearchException
     */
    SystemLoggerDTO getSystemLogger(Map<String, Object> params) throws SearchException;

    /**
     * 系统日志分页列表
     *
     * @param page
     * @return
     */
    SuccessResultList<List<SystemLoggerDTO>> listPageSystemLogger(ListPage page) throws SearchException;

    /**
     * 系统日志列表，无分页
     *
     * @param params
     * @return
     * @throws SearchException
     */
    List<SystemLoggerDTO> listSystemLogger(Map<String, Object> params) throws SearchException;

    /**
     * 统计日志数量
     *
     * @param params
     * @return
     * @throws SearchException
     */
    int countSystemLogger(Map<String, Object> params) throws SearchException;
}
